==> quickpython-0.1.1.tar.gz: quickpython-0.1.1/README.md <==
[![QuickPYTHON - Educational Interactive Coding Environment](https://raw.githubusercontent.com/timothycrosley/quickpython/master/art/logo_large.png)](https://timothycrosley.github.io/quickpython/)
_________________

[![PyPI version](https://badge.fury.io/py/quickpython.svg)](http://badge.fury.io/py/quickpython)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/quickpython/)
[![Downloads](https://pepy.tech/badge/quickpython)](https://pepy.tech/project/quickpython)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)
_________________

[Read Latest Documentation](https://timothycrosley.github.io/quickpython/) - [Browse GitHub Code Repository](https://github.com/timothycrosley/quickpython/)
_________________

![Example Usage](https://raw.githubusercontent.com/timothycrosley/quickpython/master/art/example.gif)

**QuickPYTHON** A retro-futuristic educational interactive coding environment. Powered by Python and nostalgia.

Key features

- Mouse support
- Futuristic blue color scheme
- Auto-formatting
- Integrated Debugging Support
- Quick shortcuts for creating new dataclasses, static methods, etc
- Built-in help
- Games!

## Quick Start Instructions

```bash
pip install quickpython
```

then start with

```bash
qpython
```

or

```bash
quickpython
```

*Disclaimer*: This project is provided as-is, for fun, with no guarantee of long-term support or maintenance.

==> quickpython-0.1.4.tar.gz: quickpython-0.1.4/README.md <==
[![QuickPYTHON - Educational Interactive Coding Environment](https://raw.githubusercontent.com/timothycrosley/quickpython/master/art/logo_large.png)](https://timothycrosley.github.io/quickpython/)
_________________

[![PyPI version](https://badge.fury.io/py/quickpython.svg)](http://badge.fury.io/py/quickpython)
[![Test Status](https://github.com/timothycrosley/quickpython/workflows/Test/badge.svg?branch=develop)](https://github.com/timothycrosley/quickpython/actions?query=workflow%3ATest)
[![Lint Status](https://github.com/timothycrosley/quickpython/workflows/Lint/badge.svg?branch=develop)](https://github.com/timothycrosley/quickpython/actions?query=workflow%3ALint)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/quickpython/)
[![Downloads](https://pepy.tech/badge/quickpython)](https://pepy.tech/project/quickpython)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)
[![codecov](https://codecov.io/gh/timothycrosley/quickpython/branch/master/graph/badge.svg)](https://codecov.io/gh/timothycrosley/quickpython)
[![Join the chat at https://gitter.im/timothycrosley/quickpython](https://badges.gitter.im/timothycrosley/quickpython.svg)](https://gitter.im/timothycrosley/quickpython?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
_________________

[Read Latest Documentation](https://timothycrosley.github.io/quickpython/) - [Browse GitHub Code Repository](https://github.com/timothycrosley/quickpython/)
_________________

![Example Usage](https://raw.githubusercontent.com/timothycrosley/quickpython/master/art/example.gif)

**QuickPYTHON** A retro-futuristic educational interactive coding environment. Powered by Python and nostalgia.

Key features

- Mouse support
- Futuristic blue color scheme
- Auto-formatting
- Integrated Debugging Support
- Quick shortcuts for creating new dataclasses, static methods, etc
- Built-in help
- Games!

## Quick Start Instructions

```bash
pip install quickpython
```

then start with

```bash
qpython
```

or

```bash
quickpython
```

*Disclaimer*: This project is provided as-is, for fun, with no guarantee of long-term support or maintenance.
